#include<iostream>
#include<fstream>
using namespace std;

struct FileHeader
{
	char fileType[2];
	unsigned long bfSize;
	unsigned short bfReserved1;
	unsigned short bfReserved2;
	unsigned long bfOffBits;
};

struct InfoHeader
{
	unsigned long biSize;
	unsigned long biWidth;
	unsigned long biHeight;
	unsigned short biPlanes;
	unsigned short biBitCount;
	unsigned long biCompression;
	unsigned long biSizeImage;
	unsigned long biXPixelsPerMeter;
	unsigned long biYPixelsPerMeter;
	unsigned long biClrUsed;
	unsigned long biClrImportant;
	
	//# of pixles in file
	unsigned long pixelCount;	
};

struct RGBTriple
{
	unsigned char blue;
	unsigned char green;
	unsigned char red;
};

struct Picture
{
	FileHeader fileHeader;
	InfoHeader infoHeader;
	RGBTriple* pixels;
};

void readFileHeader(FileHeader& fileHeader, ifstream& fin)
{
	fin.seekg(0);
	fin.read(fileHeader.fileType,2);
	fin.read((char*)&fileHeader.bfSize,4);
	fin.read((char*)&fileHeader.bfReserved1,2);
	fin.read((char*)&fileHeader.bfReserved2,2);
	fin.read((char*)&fileHeader.bfOffBits,4);
}

void readInfoHeader(InfoHeader& infoHeader, ifstream& fin)
{
	fin.seekg(14);
	fin.read((char*)&infoHeader.biSize,4);
	fin.read((char*)&infoHeader.biWidth,4);
	fin.read((char*)&infoHeader.biHeight,4);
	fin.read((char*)&infoHeader.biPlanes,2);
	fin.read((char*)&infoHeader.biBitCount,2);
	fin.read((char*)&infoHeader.biCompression,4);
	fin.read((char*)&infoHeader.biSizeImage,4);
	fin.read((char*)&infoHeader.biXPixelsPerMeter,4);
	fin.read((char*)&infoHeader.biYPixelsPerMeter,4);
	fin.read((char*)&infoHeader.biClrUsed,4);
	fin.read((char*)&infoHeader.biClrImportant,4);

	infoHeader.pixelCount = infoHeader.biHeight * infoHeader.biWidth;
}

void readFile(const char* fileName, Picture& picture)
{
	ifstream fin;
	fin.open(fileName,ios_base::binary);

	readFileHeader(picture.fileHeader,fin);
	readInfoHeader(picture.infoHeader,fin);

	//Get Memory for picture's Pixels
	//asks the OS for n new CRGBTriples
	picture.pixels = new RGBTriple[picture.infoHeader.pixelCount];

	//should be 54
	fin.seekg(picture.fileHeader.bfOffBits);
	int i = 0;
	for(unsigned int row = 0; row < picture.infoHeader.biHeight; row++)
	{
		for(unsigned int column = 0; column < picture.infoHeader.biWidth; column++, i ++)
		{
			fin.read((char*)&(picture.pixels[i]), 3);
		}
		
		unsigned int bytesRead =  picture.infoHeader.biWidth * 3;
		unsigned char junk;

		while(bytesRead%4 != 0)
		{
			fin.read((char*)&junk, 1);
			bytesRead++;
		}
	}

	fin.close();
}

void setDotToWhite( Picture& picture, unsigned long currentPixel )
{
	unsigned long pixel = currentPixel;
	unsigned char white = 255;
	unsigned char black = 0;

	while(picture.pixels[pixel].red == black &&
		  picture.pixels[pixel].green == black &&
		  picture.pixels[pixel].blue == black)
	{
		//Set the current pixel to white
		picture.pixels[pixel].red = white;
		picture.pixels[pixel].green = white;
		picture.pixels[pixel].blue = white;

		pixel++;

		//Set the rest of this row to white
		while(picture.pixels[pixel].red == black &&
			  picture.pixels[pixel].green == black &&
			  picture.pixels[pixel].blue == black)
		{
			picture.pixels[pixel].red = white;
			picture.pixels[pixel].green = white;
			picture.pixels[pixel].blue = white;
			pixel++;
		}

		//Increment to the beginning of the next row of the dot
		pixel = currentPixel + picture.infoHeader.biWidth;
	}	
}	


void main()
{
	char fileName[100];
	cin.getline(fileName,100);

	Picture picture;

	readFile(fileName, picture);
	
	//todo: put your code here
}
